@@ -19,7 +19,7 @@ Usage::
     list_presets_paginator: ListPresetsPaginator = client.get_paginator("list_presets")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Generator, TYPE_CHECKING
+from typing import Iterator, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_elastictranscoder.type_defs import (
     ListJobsByPipelineResponseTypeDef,
@@ -48,7 +48,7 @@ class ListJobsByPipelinePaginator(Boto3Paginator):
         PipelineId: str,
         Ascending: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListJobsByPipelineResponseTypeDef, None, None]:
+    ) -> Iterator[ListJobsByPipelineResponseTypeDef]:
         """
         [ListJobsByPipeline.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByPipeline.paginate)
         """
@@ -61,7 +61,7 @@ class ListJobsByStatusPaginator(Boto3Paginator):
 
     def paginate(
         self, Status: str, Ascending: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListJobsByStatusResponseTypeDef, None, None]:
+    ) -> Iterator[ListJobsByStatusResponseTypeDef]:
         """
         [ListJobsByStatus.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByStatus.paginate)
         """
@@ -74,7 +74,7 @@ class ListPipelinesPaginator(Boto3Paginator):
 
     def paginate(
         self, Ascending: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListPipelinesResponseTypeDef, None, None]:
+    ) -> Iterator[ListPipelinesResponseTypeDef]:
         """
         [ListPipelines.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPipelines.paginate)
         """
@@ -87,7 +87,7 @@ class ListPresetsPaginator(Boto3Paginator):
 
     def paginate(
         self, Ascending: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListPresetsResponseTypeDef, None, None]:
+    ) -> Iterator[ListPresetsResponseTypeDef]:
         """
         [ListPresets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPresets.paginate)
         """
